@@ -25,26 +25,25 @@ use HTML::TreeBuilder;
 use HTML::FormatText;
 use IO::File;
 
+has '+suffix'    => ( default => sub {'txt'} );
+
+
 sub BUILD {
     my ( $self ) = @_;
-    $self->{formatter} = $self->{format_option} ?  HTML::FormatText->new(@{$self->{format_option}}) : HTML::FormatText->new() ;
+    $self->{formatter} = $self->{format_option} ?  
+    HTML::FormatText->new(@{$self->{format_option}}) : 
+    HTML::FormatText->new() ;
     $self;
 }
 
-sub open_packer {
-    my ($self, $index) = @_;
-    my $fname = $self->format_filename("$index->{writer}-$index->{book}.txt");
-    my $fh = IO::File->new($fname, '>:utf8');
-}
-
 sub format_before_index {
-    my ( $self,$fh,  $index ) = @_;
+    my ( $self,$index ) = @_;
     my $title = "$index->{writer}  《$index->{book}》 ";
-    $fh->print("$title\n\n");
+    return $title;
 }
 
 sub format_index {
-    my ($self,$fh, $index) = @_;
+    my ($self,$index) = @_;
 
     my $num = $index->{chapter_num};
     my $r = $index->{chapter_info};
@@ -52,23 +51,18 @@ sub format_index {
     my @chap_list = map { "chap $_ ".($r->[$_-1]{title} || '') } (1 .. $num);
     my $toc = join("\n", @chap_list);
 
-    $fh->print("$toc\n\n");
+    return $toc;
 }
 
 sub format_chapter {
-    my ( $self, $fh, $chap, $id) = @_;
+    my ( $self, $chap, $id) = @_;
     $id ||= $chap->{id};
 
     my $tree = HTML::TreeBuilder->new_from_content("chap $id : $chap->{title}<br>$chap->{content}");
     my $c = $self->{formatter}->format($tree);
 
-    $fh->print("$c\n\n");
+    return $c;
 } ## end sub generate_chapter_url
 
-sub close_packer {
-    my ($self,$fh, $index) = @_;
-    $fh->close;
-}
-
 no Moo;
 1;
